@@ -64,7 +64,7 @@ void put_nl (void)
 void put_str (char *txt)
 {
   WRITE (A68G_INDENT (fd), txt);
-  A68G_INDENT (col) += (int) strlen (txt);
+  A68G_INDENT (col) += strlen (txt);
 }
 
 //! @brief Write a character.
@@ -103,7 +103,7 @@ void pretty_pragment (NODE_T * p, BOOL_T keyw)
       put_nl ();
       put_nl ();
     } else {
-      if (!keyw && (int) strlen (NPRAGMENT (p)) < 20) {
+      if (!keyw && strlen (NPRAGMENT (p)) < 20) {
         if (A68G_INDENT (col) > A68G_INDENT (ind)) {
           BLANK;
         }
@@ -126,9 +126,10 @@ void put_sym (NODE_T * p, BOOL_T keyw)
 {
   char *txt = NSYMBOL (p);
   char *sym = NCHAR_IN_LINE (p);
-  int n = 0, size = (int) strlen (txt);
+  int n = 0;
+  size_t size = strlen (txt);
   pretty_pragment (p, keyw);
-  if (txt[0] != sym[0] || (int) strlen (sym) - 1 <= size) {
+  if (txt[0] != sym[0] || (INT_T) strlen (sym) - 1 <= size) {
 // Without features..
     put_str (txt);
   } else {
@@ -1331,7 +1332,7 @@ void indenter (MODULE_T * q)
   A68G_INDENT (indentation) = OPTION_INDENT (q);
   A68G_INDENT (use_folder) = OPTION_FOLD (q);
   FILE_PRETTY_FD (q) = open (FILE_PRETTY_NAME (q), O_WRONLY | O_CREAT | O_TRUNC, A68G_PROTECTION);
-  ABEND (FILE_PRETTY_FD (q) == -1, ERROR_ACTION, __func__);
+  ABEND (FILE_PRETTY_FD (q) == A68G_NO_FILE, ERROR_ACTION, NO_TEXT);
   FILE_PRETTY_OPENED (q) = A68G_TRUE;
   A68G_INDENT (fd) = FILE_PRETTY_FD (q);
   skip_environ (TOP_NODE (q));
