@@ -592,7 +592,7 @@ void genie_getenv (NODE_T * p)
 
 void genie_fork (NODE_T * p)
 {
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+  #if defined (BUILD_WINDOWS)
     PUSH_VALUE (p, -1, A68G_INT);
   #else
     errno = 0;
@@ -640,7 +640,7 @@ void genie_exec_sub (NODE_T * p)
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
 // Now create the pipes and fork.
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+  #if defined (BUILD_WINDOWS)
     int pid = -1;
     (void) pid;
     PUSH_VALUE (p, -1, A68G_INT);
