@@ -632,6 +632,7 @@ void init_file (NODE_T * p, A68G_REF * ref_file, A68G_CHANNEL c, FILE_T s, BOOL_
   END_OF_FILE (f) = A68G_FALSE;
   TMP_FILE (f) = A68G_FALSE;
   OPENED (f) = A68G_TRUE;
+  APPEND (f) = A68G_FALSE;
   OPEN_EXCLUSIVE (f) = A68G_FALSE;
   FORMAT (f) = nil_format;
   STRING (f) = nil_ref;
@@ -652,11 +653,11 @@ void genie_init_transput (NODE_T * p)
   init_channel (&(A68G (stand_error_channel)), A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_TRUE, A68G_FALSE, A68G_FALSE);
   init_channel (&(A68G (associate_channel)), A68G_TRUE, A68G_TRUE, A68G_TRUE, A68G_TRUE, A68G_TRUE, A68G_FALSE);
   init_channel (&(A68G (skip_channel)), A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE);
-#if defined (HAVE_GNU_PLOTUTILS)
-  init_channel (&(A68G (stand_draw_channel)), A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_TRUE);
-#else
-  init_channel (&(A68G (stand_draw_channel)), A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_TRUE);
-#endif
+  #if defined (HAVE_GNU_PLOTUTILS)
+    init_channel (&(A68G (stand_draw_channel)), A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_TRUE);
+  #else
+    init_channel (&(A68G (stand_draw_channel)), A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_FALSE, A68G_TRUE);
+  #endif
 // Files.
   init_file (p, &(A68G (stand_in)), A68G (stand_in_channel), A68G_STDIN, A68G_TRUE, A68G_FALSE, A68G_TRUE, "A68G_STANDIN");
   init_file (p, &(A68G (stand_out)), A68G (stand_out_channel), A68G_STDOUT, A68G_FALSE, A68G_TRUE, A68G_TRUE, "A68G_STANDOUT");
@@ -827,6 +828,60 @@ void genie_open (NODE_T * p)
   FILE_ENTRY (file) = -1;
   CHANNEL (file) = channel;
   OPENED (file) = A68G_TRUE;
+  APPEND (file) = A68G_FALSE;
+  OPEN_EXCLUSIVE (file) = A68G_FALSE;
+  READ_MOOD (file) = A68G_FALSE;
+  WRITE_MOOD (file) = A68G_FALSE;
+  CHAR_MOOD (file) = A68G_FALSE;
+  DRAW_MOOD (file) = A68G_FALSE;
+  TMP_FILE (file) = A68G_FALSE;
+  size_t size = a68g_string_size (p, ref_iden);
+  if (INITIALISED (&(IDENTIFICATION (file))) && !IS_NIL (IDENTIFICATION (file))) {
+    UNBLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
+  }
+  IDENTIFICATION (file) = heap_generator (p, M_C_STRING, 1 + size);
+  BLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
+  ASSERT (a_to_c_string (p, DEREF (char, &IDENTIFICATION (file)), ref_iden) != NO_TEXT);
+  TERMINATOR (file) = nil_ref;
+  FORMAT (file) = nil_format;
+  FD (file) = A68G_NO_FILE;
+  if (INITIALISED (&(STRING (file))) && !IS_NIL (STRING (file))) {
+    UNBLOCK_GC_HANDLE (DEREF (A68G_REF, &STRING (file)));
+  }
+  STRING (file) = nil_ref;
+  STRPOS (file) = 0;
+  DEVICE_MADE (&DEVICE (file)) = A68G_FALSE;
+  STREAM (&DEVICE (file)) = NO_STREAM;
+  set_default_event_procedures (file);
+  {
+    struct stat status;
+    if (stat (DEREF (char, &IDENTIFICATION (file)), &status) == 0) {
+      PUSH_VALUE (p, (S_ISREG (ST_MODE (&status)) != 0 ? 0 : ENOENT), A68G_INT);
+    } else {
+      PUSH_VALUE (p, errno, A68G_INT);
+    }
+    errno = 0;
+  }
+}
+
+//! @brief PROC (REF FILE, STRING, CHANNEL) INT append
+
+void genie_append (NODE_T * p)
+{
+  A68G_CHANNEL channel;
+  POP_OBJECT (p, &channel, A68G_CHANNEL);
+  A68G_REF ref_iden;
+  POP_REF (p, &ref_iden);
+  CHECK_REF (p, ref_iden, M_REF_STRING);
+  A68G_REF ref_file;
+  POP_REF (p, &ref_file);
+  CHECK_REF (p, ref_file, M_REF_FILE);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
+  STATUS (file) = INIT_MASK;
+  FILE_ENTRY (file) = -1;
+  CHANNEL (file) = channel;
+  OPENED (file) = A68G_TRUE;
+  APPEND (file) = A68G_TRUE;
   OPEN_EXCLUSIVE (file) = A68G_FALSE;
   READ_MOOD (file) = A68G_FALSE;
   WRITE_MOOD (file) = A68G_FALSE;
@@ -879,6 +934,7 @@ void genie_establish (NODE_T * p)
   FILE_ENTRY (file) = -1;
   CHANNEL (file) = channel;
   OPENED (file) = A68G_TRUE;
+  APPEND (file) = A68G_FALSE;
   OPEN_EXCLUSIVE (file) = A68G_TRUE;
   READ_MOOD (file) = A68G_FALSE;
   WRITE_MOOD (file) = A68G_FALSE;
@@ -924,6 +980,7 @@ void genie_create (NODE_T * p)
   FILE_ENTRY (file) = -1;
   CHANNEL (file) = channel;
   OPENED (file) = A68G_TRUE;
+  APPEND (file) = A68G_FALSE;
   OPEN_EXCLUSIVE (file) = A68G_FALSE;
   READ_MOOD (file) = A68G_FALSE;
   WRITE_MOOD (file) = A68G_FALSE;
@@ -972,6 +1029,7 @@ void genie_associate (NODE_T * p)
   FILE_ENTRY (file) = -1;
   CHANNEL (file) = A68G (associate_channel);
   OPENED (file) = A68G_TRUE;
+  APPEND (file) = A68G_FALSE;
   OPEN_EXCLUSIVE (file) = A68G_FALSE;
   READ_MOOD (file) = A68G_FALSE;
   WRITE_MOOD (file) = A68G_FALSE;
@@ -1009,13 +1067,13 @@ void genie_close (NODE_T * p)
     return;
   }
   DEVICE_MADE (&DEVICE (file)) = A68G_FALSE;
-#if defined (HAVE_GNU_PLOTUTILS)
-  if (DEVICE_OPENED (&DEVICE (file))) {
-    ASSERT (close_device (p, file) == A68G_TRUE);
-    STREAM (&DEVICE (file)) = NO_STREAM;
-    return;
-  }
-#endif
+  #if defined (HAVE_GNU_PLOTUTILS)
+    if (DEVICE_OPENED (&DEVICE (file))) {
+      ASSERT (close_device (p, file) == A68G_TRUE);
+      STREAM (&DEVICE (file)) = NO_STREAM;
+      return;
+    }
+  #endif
   FD (file) = A68G_NO_FILE;
   OPENED (file) = A68G_FALSE;
   unblock_transput_buffer (TRANSPUT_BUFFER (file));
@@ -1036,17 +1094,17 @@ void genie_lock (NODE_T * p)
     return;
   }
   DEVICE_MADE (&DEVICE (file)) = A68G_FALSE;
-#if defined (HAVE_GNU_PLOTUTILS)
-  if (DEVICE_OPENED (&DEVICE (file))) {
-    ASSERT (close_device (p, file) == A68G_TRUE);
-    STREAM (&DEVICE (file)) = NO_STREAM;
-    return;
-  }
-#endif
-#if defined (BUILD_UNIX)
-  errno = 0;
-  ASSERT (fchmod (FD (file), (mode_t) 0x0) != -1);
-#endif
+  #if defined (HAVE_GNU_PLOTUTILS)
+    if (DEVICE_OPENED (&DEVICE (file))) {
+      ASSERT (close_device (p, file) == A68G_TRUE);
+      STREAM (&DEVICE (file)) = NO_STREAM;
+      return;
+    }
+  #endif
+  #if defined (BUILD_UNIX)
+    errno = 0;
+    ASSERT (fchmod (FD (file), (mode_t) 0x0) != -1);
+  #endif
   if (FD (file) != A68G_NO_FILE && close (FD (file)) == -1) {
     diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_LOCK);
     exit_genie (p, A68G_RUNTIME_ERROR);
@@ -1072,13 +1130,13 @@ void genie_erase (NODE_T * p)
     return;
   }
   DEVICE_MADE (&DEVICE (file)) = A68G_FALSE;
-#if defined (HAVE_GNU_PLOTUTILS)
-  if (DEVICE_OPENED (&DEVICE (file))) {
-    ASSERT (close_device (p, file) == A68G_TRUE);
-    STREAM (&DEVICE (file)) = NO_STREAM;
-    return;
-  }
-#endif
+  #if defined (HAVE_GNU_PLOTUTILS)
+    if (DEVICE_OPENED (&DEVICE (file))) {
+      ASSERT (close_device (p, file) == A68G_TRUE);
+      STREAM (&DEVICE (file)) = NO_STREAM;
+      return;
+    }
+  #endif
   if (FD (file) != A68G_NO_FILE && close (FD (file)) == -1) {
     diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_SCRATCH);
     exit_genie (p, A68G_RUNTIME_ERROR);
