@@ -31,7 +31,7 @@
 
 #define HAVE_GSL
 #define HAVE_GNU_PLOTUTILS
-#define HAVE_MATHLIB
+#define HAVE_R_MATHLIB
 #define HAVE_QUADMATH
 
 #undef HAVE_GNU_MPFR
@@ -101,6 +101,8 @@
 #define HAVE_TIME_H
 #define HAVE_UNISTD_H
 
+#undef HAVE_SIGACTION
+
 #endif // BUILD_WIN32
 
 // Name of package
@@ -116,11 +118,11 @@
 #define PACKAGE_BUGREPORT "Marcel van der Veer <algol68g@xs4all.nl>"
 
 // Define to the full name and version of this package.
-#define PACKAGE_STRING "algol68g 3.9.10"
+#define PACKAGE_STRING "algol68g 3.10.4"
 
 // Define to the version of this package.
-#define PACKAGE_VERSION "3.9.10"
+#define PACKAGE_VERSION "3.10.4"
 
 // Version number of package
-#define VERSION "3.9.10"
+#define VERSION "3.10.4"
 
